# Licensed under a 3-clause BSD style license - see LICENSE.rst

"""
SOLARSYSTEM.JPL.SBDB
--------------------

:author: Michael Mommert (mommermiscience@gmail.com)
"""

from ....jplsbdb import SBDB, SBDBClass


__all__ = ["SBDB", "SBDBClass"]
